跳到主要内容

Stream

搜索

结构体 Stream 

源代码
pub struct Stream<'a> { /* 私有字段 */ }

实现

源代码

impl<'a> Stream<'a>

源代码

pub unsafe fn wrap(context: &Context, index: usize) -> Stream<'_>

源代码

pub unsafe fn as_ptr(&self) -> *const AVStream

源代码

impl<'a> Stream<'a>

源代码

pub fn id(&self) -> i32

源代码

pub fn parameters(&self) -> Parameters

源代码

pub fn index(&self) -> usize

源代码

pub fn time_base(&self) -> Rational

源代码

pub fn start_time(&self) -> i64

源代码

pub fn duration(&self) -> i64

源代码

pub fn frames(&self) -> i64

源代码

pub fn disposition(&self) -> Disposition

源代码

pub fn discard(&self) -> Discard

源代码

pub fn side_data(&self) -> SideDataIter<'_>

源代码

pub fn rate(&self) -> Rational

源代码

pub fn avg_frame_rate(&self) -> Rational

源代码

pub fn metadata(&self) -> DictionaryRef<'_>

trait 实现

源代码

impl<'a> Debug for Stream<'a>

源代码

fn fmt(&self, f: &mut Formatter<'_>) -> Result

使用给定的格式化器格式化该值。 阅读更多
源代码

impl<'a> PartialEq for Stream<'a>

源代码

fn eq(&self, other: &Self) -> bool

Tests for self and other values to be equal, and is used by ==.
1.0.0 · 源代码

fn ne(&self, other: &Rhs) -> bool

测试 !=。默认实现几乎总是足够的,没有充分理由不应被重写。
源代码

impl<'a> Eq for Stream<'a>

自动 trait 实现



impl<'a> Freeze for Stream<'a>



impl<'a> RefUnwindSafe for Stream<'a>



impl<'a> !Send for Stream<'a>



impl<'a> !Sync for Stream<'a>



impl<'a> Unpin for Stream<'a>



impl<'a> UnsafeUnpin for Stream<'a>



impl<'a> UnwindSafe for Stream<'a>

blanket 实现

源代码

impl<T> Any for T
where T: 'static + ?Sized,

源代码

fn type_id(&self) -> TypeId

获取 selfTypeId阅读更多
源代码

impl<T> Borrow<T> for T
where T: ?Sized,

源代码

fn borrow(&self) -> &T

从拥有的值不可变地借用。 阅读更多
源代码

impl<T> BorrowMut<T> for T
where T: ?Sized,

源代码

fn borrow_mut(&mut self) -> &mut T

从拥有的值可变地借用。 阅读更多
源代码

impl<T> From<T> for T

源代码

fn from(t: T) -> T

原样返回参数。

源代码

impl<T, U> Into<U> for T
where U: From<T>,

源代码

fn into(self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of From<T> for U 实现选择执行的操作。

源代码

impl<T, U> TryFrom<U> for T
where U: Into<T>,

源代码

type Error = Infallible

转换出错时返回的类型。
源代码

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

执行该转换。
源代码

impl<T, U> TryInto<U> for T
where U: TryFrom<T>,

源代码

type Error = <U as TryFrom<T>>::Error

转换出错时返回的类型。
源代码

fn try_into(self) -> Result<U, <U as TryFrom<T>>::Error>

执行该转换。